/* packet-myfoo.c
 * Routines for MYFOO packet dissection
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <glib.h>
#include <epan/packet.h>
#include <epan/conversation.h>
#include <epan/asn1.h>

#include <stdio.h>
#include <string.h>

#include "packet-per.h"
#include "packet-myfoo.h"

#define PNAME  "MYFOO Protocol"
#define PSNAME "MYFOO"
#define PFNAME "myfoo"
#define MYFOO_PORT 5001    /* UDP port */
static dissector_handle_t myfoo_handle=NULL;

void proto_reg_handoff_myfoo(void);
void proto_register_myfoo(void);

/* Initialize the protocol and registered fields */
static int proto_myfoo = -1;
static int global_myfoo_port = MYFOO_PORT;

#include "packet-myfoo-hf.c"

/* Initialize the subtree pointers */
static int ett_myfoo = -1;

#include "packet-myfoo-ett.c"

#include "packet-myfoo-fn.c"

static void
dissect_myfoo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
{
        proto_item      *myfoo_item = NULL;
        proto_tree      *myfoo_tree = NULL;
        int                     offset = 0;

        /* make entry in the Protocol column on summary display */
	/* if (check_col(pinfo->cinfo, COL_PROTOCOL)) */
                col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);

    /* create the myfoo protocol tree */
    if (tree) {
        myfoo_item = proto_tree_add_item(tree, proto_myfoo, tvb, 0, -1, FALSE);
        myfoo_tree = proto_item_add_subtree(myfoo_item, ett_myfoo);

        dissect_MYFOO_MESSAGE_PDU(tvb, pinfo, myfoo_tree, NULL);
    }
}
/*--- proto_register_myfoo -------------------------------------------*/
void proto_register_myfoo(void) {

  /* List of fields */
  static hf_register_info hf[] = {

#include "packet-myfoo-hfarr.c"
  };

  /* List of subtrees */
  static gint *ett[] = {
                  &ett_myfoo,
#include "packet-myfoo-ettarr.c"
  };

  /* Register protocol */
  proto_myfoo = proto_register_protocol(PNAME, PSNAME, PFNAME);
  /* Register fields and subtrees */
  proto_register_field_array(proto_myfoo, hf, array_length(hf));
  proto_register_subtree_array(ett, array_length(ett));



}

/*--- proto_reg_handoff_myfoo ---------------------------------------*/
void
proto_reg_handoff_myfoo(void)
{
    static gboolean inited = FALSE;

    if( !inited ) {

        myfoo_handle = create_dissector_handle(dissect_myfoo,
                                                     proto_myfoo);
        dissector_add_uint("udp.port", global_myfoo_port, myfoo_handle);
	/* dissector_add_uint_with_preference("udp.port", global_myfoo_port, myfoo_handle); */

        inited = TRUE;
    }

}
